@@ -1,8 +1,8 @@
-/* $Id: kassa.c,v 5.41 2013/11/24 08:23:03 sasa Exp $ */
+/* $Id:$ */
 /*10.10.2011	30.04.1999	Белых А.И. 	kassa.c
 Программа работы с кассовым аппаратом 
 */
-#define         DVERSIQ "05.06.2008"
+#define         DVERSIQ "04.01.2026"
 #include        <sys/types.h>
 #include        <sys/stat.h>
 #include        <pwd.h>
@@ -354,19 +354,19 @@ naz:;
 clear();
 attron(A_BOLD);
 attron(A_BLINK);
-attron(COLOR_PAIR(COLOR_RED*COLORS+COLOR_BLACK));
+attron(COLOR_PAIR(COLOR_RED*XTERM_COLORS+COLOR_BLACK));
 mvprintw(0,0,"\
                           У в а г а !!!\n\n");
 attroff(A_BLINK);
-attroff(COLOR_PAIR(COLOR_RED*COLORS+COLOR_BLACK));
+attroff(COLOR_PAIR(COLOR_RED*XTERM_COLORS+COLOR_BLACK));
                       
-attron(COLOR_PAIR(COLOR_GREEN*COLORS+COLOR_BLACK));
+attron(COLOR_PAIR(COLOR_GREEN*XTERM_COLORS+COLOR_BLACK));
 printw("\
        Перед виконанням цієї операції необхідно скинути накопичення\n\
             проданого товару в пам'яті касового апарату.\n\
     Для отримання більш докладної інформації з цього питання виберіть\n\
                  в меню \"Просмотр документації\".");
-attroff(COLOR_PAIR(COLOR_BLUE*COLORS+COLOR_BLACK));
+attroff(COLOR_PAIR(COLOR_BLUE*XTERM_COLORS+COLOR_BLACK));
 attroff(A_BOLD);
 
 VVOD MENU(3);
