@@ -1,5 +1,5 @@
 /*$Id: rnnrd5.c,v 5.40 2014/07/31 07:09:17 sasa Exp $*/
-/*07.04.2021	19.01.2015	Белых А.И.	rnnrd5_8.c
+/*07.04.2021	19.01.2015	Белых А.И.	rnnrd5_6.c
 Распечатка додатка 5
 */
 #include <ctype.h>
@@ -7,14 +7,14 @@
 #include "buhg.h"
 #include "rnn_d5.h"
 
-void rnnrd5_8_sap2(FILE *ff);
-void rnnrd5_8_sap(FILE *ff_svod);
-void rnn_rk5_6_kon1(double suma_bez_nds2,double suma_nds2,double suma_nds_7,double os_sr21,double os_sr22,FILE *ff_svod,FILE*);
-void rnnrd5_8_endras(class rnn_d5 *dod5,double,int,FILE *ff_svod,FILE *ff_xml);
+void rnnrd5_6_sap2(FILE *ff);
+void rnnrd5_6_sap(FILE *ff_svod);
+void rnn_rk5_6_kon1(double suma_bez_nds2,double suma_nds2,double suma_nds_7,double os_sr21,double os_sr22,double inh1,double inh2,double inh3,FILE *ff_svod,FILE*);
+void rnnrd5_6_endras(class rnn_d5 *dod5,double,int,FILE *ff_svod,FILE *ff_xml);
 
 extern class iceb_rnfxml_data rek_zag_nn;
 
-int rnnrd5_8(short dn,short mn,short gn,short dk,short mk,short gk,
+int rnnrd5_6(short dn,short mn,short gn,short dk,short mk,short gk,
 char *imaf_xml,char *imaf_svod_naim,
 char *imaf_xml_dot,char *imaf_svod_dot, /*Дополнительные отчёты*/
 double proc_dot, /*Процент дотации*/
@@ -118,11 +118,11 @@ if(ff_svod_dot != NULL)
   iceb_t_zagolov("Додаток 2",dn,mn,gn,dk,mk,gk,ff_svod_dot);
 
 if(ff_svod_dot != NULL)
-  rnnrd5_8_sap(ff_svod_dot);
+  rnnrd5_6_sap(ff_svod_dot);
 
 double inh1=0.,inh2=0.,inh3=0.;
 
-rnnrd5_8_sap(ff_svod_naim);
+rnnrd5_6_sap(ff_svod_naim);
 
 int nomer_str=0;
 double suma_bez_nds=0.;
@@ -135,8 +135,6 @@ class iceb_tu_str iceb_tu_period("");
 short m=0,g=0;
 class iceb_tu_str in2("");
 
-/********************** податкові зобов'язання*************************************/
-
 for(int kkk=0; kkk < dod5->innn2.kolih(); kkk++)
  {
   for(int ii=0; ii < dod5->innn_per2.kolih(); ii++)
@@ -149,9 +147,7 @@ for(int kkk=0; kkk < dod5->innn2.kolih(); kkk++)
     || iceb_tu_SRAV(in2.ravno(),"100000000000",0) == 0 
     || iceb_tu_SRAV(in2.ravno(),"200000000000",0) == 0 
     || iceb_tu_SRAV(in2.ravno(),"300000000000",0) == 0 
-    || iceb_tu_SRAV(in2.ravno(),"400000000000",0) == 0 
-    || iceb_tu_SRAV(in2.ravno(),"500000000000",0) == 0 
-    || iceb_tu_SRAV(in2.ravno(),"600000000000",0) == 0 )  /*освобдждено от НДС*/
+    || iceb_tu_SRAV(in2.ravno(),"400000000000",0) == 0 )  /*освобдждено от НДС*/
      {
       inh1+=dod5->suma_bez_nds2.ravno(ii);
       inh2+=dod5->suma_nds2.ravno(ii);
@@ -242,131 +238,21 @@ if(proc_dot != 0)
   inhi3=iceb_tu_okrug(inhi3,0.01);
  }
 
-if(inh1 == 0. && inh2 == 0.)
- {
-  fprintf(ff_xml,"   <R001G4 xsi:nil=\"true\"/>\n");
-  fprintf(ff_xml,"   <R001G5 xsi:nil=\"true\"/>\n");
-  fprintf(ff_xml,"   <R001G6 xsi:nil=\"true\"/>\n");
- }
-else
- {
-  fprintf(ff_xml,"   <R001G4>%.2f</R001G4>\n",inh1);
-  fprintf(ff_xml,"   <R001G5>%.2f</R001G5>\n",inh2);
-  fprintf(ff_xml,"   <R001G6>%.2f</R001G6>\n",inh3);
- } 
-
-fprintf(ff_svod_naim,"\
-------------------------------------------------------------------------------\n");
-if(inh1 == 0. && inh2 == 0.)
-  fprintf(ff_svod_naim,"\
-Інші                                   |               |          |          |\n");
-else
-  fprintf(ff_svod_naim,"\
-Інші                                   |%15.2f|%10.2f|%10.2f\n",inh1,inh2,inh3);
-
-fprintf(ff_svod_naim,"\
-------------------------------------------------------------------------------\n");
-
-/*для расчёта по процентам пока не сделал*/
-
-char inn_b[32];
-double itogo[3];
-
-for(int nom=0; nom < 6; nom++)
- {
-  sprintf(inn_b,"%d00000000000",nom+1);
-  memset(itogo,'\0',sizeof(itogo));
-   
-  for(int ii=0; ii < dod5->innn_per2.kolih(); ii++)
-   {
-    iceb_tu_polen(dod5->innn_per2.ravno(ii),&in2,1,'|');  
-    if(iceb_tu_SRAV(inn_b,in2.ravno(),0) != 0)
-     continue;
-
-    itogo[0]+=dod5->suma_bez_nds2.ravno(ii);
-    itogo[1]+=dod5->suma_nds2.ravno(ii);
-    itogo[2]+=dod5->suma_nds2_7.ravno(ii);
-
-   }
-  
-  fprintf(ff_svod_naim,"%-44s %10.2f %10.2f %10.2f\n",inn_b,itogo[0],itogo[1],itogo[2]);
-
-  if(nom == 0)
-   {
-    fprintf(ff_xml,"   <R0011G4>%.2f</R0011G4>\n",itogo[0]);
-    fprintf(ff_xml,"   <R0011G5>%.2f</R0011G5>\n",itogo[1]);
-    fprintf(ff_xml,"   <R0011G6>%.2f</R0011G6>\n",itogo[1]);
-   }
-  if(nom == 1)
-   {
-    fprintf(ff_xml,"   <R0012G4>%.2f</R0012G4>\n",itogo[0]);
-    fprintf(ff_xml,"   <R0012G5>%.2f</R0012G5>\n",itogo[1]);
-    fprintf(ff_xml,"   <R0012G6>%.2f</R0012G6>\n",itogo[1]);
-   }
-  if(nom == 2)
-   {
-    fprintf(ff_xml,"   <R0013G4>%.2f</R0013G4>\n",itogo[0]);
-    fprintf(ff_xml,"   <R0013G5>%.2f</R0013G5>\n",itogo[1]);
-    fprintf(ff_xml,"   <R0013G6>%.2f</R0013G6>\n",itogo[1]);
-   }
-  if(nom == 3)
-   {
-    fprintf(ff_xml,"   <R0014G4>%.2f</R0014G4>\n",itogo[0]);
-    fprintf(ff_xml,"   <R0014G5>%.2f</R0014G5>\n",itogo[1]);
-    fprintf(ff_xml,"   <R0014G6>%.2f</R0014G6>\n",itogo[1]);
-   }
-  if(nom == 4)
-   {
-    fprintf(ff_xml,"   <R0015G4>%.2f</R0015G4>\n",itogo[0]);
-    fprintf(ff_xml,"   <R0015G5>%.2f</R0015G5>\n",itogo[1]);
-    fprintf(ff_xml,"   <R0015G6>%.2f</R0015G6>\n",itogo[1]);
-   }
-  if(nom == 5)
-   {
-    fprintf(ff_xml,"   <R0016G4>%.2f</R0016G4>\n",itogo[0]);
-    fprintf(ff_xml,"   <R0016G5>%.2f</R0016G5>\n",itogo[1]);
-    fprintf(ff_xml,"   <R0016G6>%.2f</R0016G6>\n",itogo[1]);
-   }
- }
-
-
-fprintf(ff_svod_naim,"\
-------------------------------------------------------------------------------\n");
-
-fprintf(ff_svod_naim,"\
-Усього за звітний період               |%15.2f|%10.2f|%10.2f|\n",
-i_suma_bez_nds+inh1,i_suma_nds+inh2,i_suma_nds_7);
-//suma_bez_nds2,suma_nds2,suma_nds2_7);
-
-
-fprintf(ff_svod_naim,"\
-------------------------------------------------------------------------------\n");
-
-fprintf(ff_svod_naim,"\
-постачання необоротних активів         |%15.2f|%10.2f|          |\n",
-os1,os2);
-//os_sr21,os_sr22);
-
-fprintf(ff_svod_naim,"\
-------------------------------------------------------------------------------\n");
-
-rnn_rk5_6_kon1(i_suma_bez_nds+inh1,i_suma_nds+inh2,i_suma_nds_7,os1,os2,ff_svod_naim,ff_xml);
-
-/*для расчёта по прочентам пока не сделали*/
+rnn_rk5_6_kon1(i_suma_bez_nds+inh1,i_suma_nds+inh2,i_suma_nds_7,os1,os2,inhi1,inhi2,inhi3,ff_svod_naim,ff_xml);
 
 if(ff_svod_dot != NULL)
   rnn_rk5_6_kon1(dod5->suma_bez_nds2.suma()-i_suma_bez_nds+inh1-inhi1,
   dod5->suma_nds2.suma()-i_suma_nds+inh2-inhi2,\
   dod5->suma_nds2_7.suma()-i_suma_nds_7+inh3-inhi3,\
-  dod5->os_sr2[0]-os1,dod5->os_sr2[1]-os2,ff_svod_dot,ff_xml_dot);
+  dod5->os_sr2[0]-os1,dod5->os_sr2[1]-os2,inh1-inhi1,inh2-inhi2,inh3-inhi3,ff_svod_dot,ff_xml_dot);
 
 
 /****************************** податковый кредит***********************************/
 
-rnnrd5_8_sap2(ff_svod_naim);
+rnnrd5_6_sap2(ff_svod_naim);
 
 if(ff_svod_dot != NULL)
- rnnrd5_8_sap2(ff_svod_dot);
+ rnnrd5_6_sap2(ff_svod_dot);
                   
 
 class iceb_tu_str in1("");
@@ -448,10 +334,10 @@ fprintf(ff_svod_naim,"\
 Разом                                       |%10.2f|%10.2f|%10.2f|\n",
 dod5->suma_bez_nds1.suma(),dod5->suma_nds1.suma(),dod5->suma_nds1_7.suma());
 
-rnnrd5_8_endras(dod5,proc_dot,0,ff_svod_naim,ff_xml);
+rnnrd5_6_endras(dod5,proc_dot,0,ff_svod_naim,ff_xml);
 
 if(ff_svod_dot != NULL)
-  rnnrd5_8_endras(dod5,proc_dot,1,ff_svod_dot,ff_xml_dot);
+  rnnrd5_6_endras(dod5,proc_dot,1,ff_svod_dot,ff_xml_dot);
 
 
 return(0);
@@ -461,7 +347,7 @@ return(0);
 /*шапка додатка 5 и 2*/
 /**********************************/
 
-void rnnrd5_8_sap(FILE *ff_svod)
+void rnnrd5_6_sap(FILE *ff_svod)
 {
 
 
@@ -488,9 +374,21 @@ double suma_nds2,
 double suma_nds2_7,
 double os_sr21,
 double os_sr22,
-FILE *ff_svod,FILE *ff_xml)
+double inh1,double inh2,double inh3,FILE *ff_svod,FILE *ff_xml)
 {
 
+if(inh1 == 0. && inh2 == 0.)
+ {
+  fprintf(ff_xml,"   <R001G4 xsi:nil=\"true\"/>\n");
+  fprintf(ff_xml,"   <R001G5 xsi:nil=\"true\"/>\n");
+  fprintf(ff_xml,"   <R001G6 xsi:nil=\"true\"/>\n");
+ }
+else
+ {
+  fprintf(ff_xml,"   <R001G4>%.2f</R001G4>\n",inh1);
+  fprintf(ff_xml,"   <R001G5>%.2f</R001G5>\n",inh2);
+  fprintf(ff_xml,"   <R001G6>%.2f</R001G6>\n",inh3);
+ } 
 
 fprintf(ff_xml,"   <R010G4>%.2f</R010G4>\n",suma_bez_nds2);
 fprintf(ff_xml,"   <R010G5>%.2f</R010G5>\n",suma_nds2);
@@ -507,12 +405,39 @@ else
  fprintf(ff_xml,"   <R011G5>%.2f</R011G5>\n",os_sr22);
 
 
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+if(inh1 == 0. && inh2 == 0.)
+  fprintf(ff_svod,"\
+Інші                                   |               |          |          |\n");
+else
+  fprintf(ff_svod,"\
+Інші                                   |%15.2f|%10.2f|%10.2f\n",inh1,inh2,inh3);
+
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+
+fprintf(ff_svod,"\
+Усього за звітний період  (рядок 1 дек-|               |          |          |\n\
+ларації),в тому числі:                 |%15.2f|%10.2f|%10.2f|\n",
+suma_bez_nds2,suma_nds2,suma_nds2_7);
+
+
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+
+fprintf(ff_svod,"\
+постачання необоротних активів         |%15.2f|%10.2f|          |\n",os_sr21,os_sr22);
+
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+
 
 }
 /******************/
 /*концовка*/
 /******************/
-void rnnrd5_8_endras(class rnn_d5 *dod5,
+void rnnrd5_6_endras(class rnn_d5 *dod5,
 double proc_dot,
 int metka_v,    /*0-основной 1-дополнительный*/
 FILE *ff_svod,FILE *ff_xml)
@@ -555,14 +480,23 @@ if(proc_dot != 0.)
 fprintf(ff_svod,"\
 ------------------------------------------------------------------------------\n");
 fprintf(ff_svod,"\
-Усього за звіт. перідо                      |%10.2f|%10.2f|%10.2f|\n",
+Усього за місяць (квартал)(рядок 10.1 декла-|          |          |          |\n\
+рації), в тому числі:                       |%10.2f|%10.2f|%10.2f|\n",
 suma_bez_nds,suma_nds,suma_nds_7);
 
 
 fprintf(ff_svod,"\
 ------------------------------------------------------------------------------\n");
 fprintf(ff_svod,"\
-придбання (будівництво, спорудження)        |%10.2f|%10.2f|          |\n",os1,os2);
+придбання (будівництво, спорудження)        |%10.2f|%10.2f|          |\n\
+основних фондів                             |          |          |          |\n",os1,os2);
+
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+fprintf(ff_svod,"\
+проведення розрахунків комісіонером/повірен-|          |          |          |\n\
+ним за товари (послуги) на умовах передба-  |          |          |          |\n\
+чених п.4.7 ст. 4 Закону                    |          |          |          |\n");
 
 fprintf(ff_svod,"\
 ------------------------------------------------------------------------------\n");
@@ -585,6 +519,181 @@ if(os2 == 0.)
 else
   fprintf(ff_xml,"   <R021G5>%.2f</R021G5>\n",os2);
 
+double i_suma_bez_nds=0.;
+double i_suma_nds=0.;
+double i_suma_nds_7=0.;
+class iceb_tu_str iceb_tu_period("");
+short m=0,g=0;
+class iceb_tu_str in1("");
+
+fprintf(ff_svod,"\
+Операції з придбання з ПДВ, які не надають права формування\n\
+            податкового кредиту\n");
+
+
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+
+
+for(int kkk=0; kkk < dod5->innn1d.kolih(); kkk++)
+ for(int nomer=0; nomer < dod5->innn_per1d.kolih(); nomer++)
+  {
+   iceb_tu_polen(dod5->innn_per1d.ravno(nomer),&in1,1,'|');  
+   if(iceb_tu_SRAV(dod5->innn1d.ravno(kkk),in1.ravno(),0) != 0)
+     continue;
+
+   iceb_tu_polen(dod5->innn_per1d.ravno(nomer),&iceb_tu_period,2,'|');  
+   iceb_tu_rsdat1(&m,&g,iceb_tu_period.ravno());
+
+   suma_bez_nds=dod5->suma_bez_nds1d.ravno(nomer);
+   suma_nds=dod5->suma_nds1d.ravno(nomer);
+   suma_nds_7=dod5->suma_nds1d_7.ravno(nomer);
+
+   if(proc_dot != 0.)
+    {
+     suma_bez_nds=suma_bez_nds*(100.0-proc_dot)/100.;
+     suma_bez_nds=iceb_tu_okrug(suma_bez_nds,0.01);
+
+      suma_nds=suma_nds*(100.0-proc_dot)/100.;
+      suma_nds=iceb_tu_okrug(suma_nds,0.01);
+
+      suma_nds_7=suma_nds_7*(100.0-proc_dot)/100.;
+      suma_nds_7=iceb_tu_okrug(suma_nds_7,0.01);
+      if(metka_v == 1)
+       {
+        suma_bez_nds=dod5->suma_bez_nds1.suma()-suma_bez_nds;
+        suma_nds=dod5->suma_nds1.suma()-suma_nds;
+        suma_nds_7=dod5->suma_nds1_7.suma()-suma_nds_7;
+       }
+     }
+
+    i_suma_bez_nds+=suma_bez_nds;
+    i_suma_nds+=suma_nds;
+    i_suma_nds_7+=suma_nds_7;
+
+    fprintf(ff_svod,"%5d|%-*s|%02d.%04d          |%10.2f|%10.2f|%10.2f|%s\n",
+    nomer+1,
+    iceb_tu_kolbait(20,dod5->innn1d.ravno(kkk)),dod5->innn1d.ravno(kkk),
+    m,g,suma_bez_nds,suma_nds,suma_nds_7,
+    dod5->naim_kontr1d.ravno(kkk));
+
+    if(dod5->innn1d.ravno(kkk)[0] == '\0' ||  isdigit(dod5->innn1d.ravno(kkk)[0]) == 0)  //Значит символ не число
+     fprintf(ff_xml,"   <T3RXXXXG2 xsi:nil=\"true\" ROWNUM=\"%d\"/>\n",nomer+1);
+    else  
+      fprintf(ff_xml,"   <T3RXXXXG2 ROWNUM=\"%d\">%s</T3RXXXXG2>\n",nomer+1,dod5->innn1d.ravno(kkk));
+
+    fprintf(ff_xml,"   <T3RXXXXG3A ROWNUM=\"%d\">%d</T3RXXXXG3A>\n",nomer+1,m);
+    fprintf(ff_xml,"   <T3RXXXXG3B ROWNUM=\"%d\">%d</T3RXXXXG3B>\n",nomer+1,g);
+    fprintf(ff_xml,"   <T3RXXXXG4 ROWNUM=\"%d\">%.2f</T3RXXXXG4>\n",nomer+1,suma_bez_nds);
+    fprintf(ff_xml,"   <T3RXXXXG5  ROWNUM=\"%d\">%.2f</T3RXXXXG5>\n",nomer+1,suma_nds);
+    fprintf(ff_xml,"   <T3RXXXXG6  ROWNUM=\"%d\">%.2f</T3RXXXXG6>\n",nomer+1,suma_nds_7);
+
+  }
+
+if(dod5->innn1d.kolih() == 0)
+ {
+  fprintf(ff_svod,"\
+     |                    |                 |          |          |          |\n");
+ }
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+
+fprintf(ff_svod,"\
+Усього за звітний період                    |%10.2f|%10.2f|%10.2f|\n",i_suma_bez_nds,i_suma_nds,suma_nds_7);
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+
+
+
+
+if(i_suma_bez_nds == 0.)
+  fprintf(ff_xml,"   <R03G4 xsi:nil=\"true\"/>\n");
+else
+  fprintf(ff_xml,"   <R03G4>%.2f</R03G4>\n",i_suma_bez_nds);
+
+if(i_suma_nds == 0.)
+  fprintf(ff_xml,"   <R03G5 xsi:nil=\"true\"/>\n");
+else
+  fprintf(ff_xml,"   <R03G5>%.2f</R03G5>\n",i_suma_nds);
+
+fprintf(ff_xml,"   <R03G6>%.2f</R03G6>\n",i_suma_nds_7);
+
+
+fprintf(ff_svod,"Операції з придбання без податку на додану вартість\n");
+
+
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+for(int kkk=0; kkk < dod5->innn1d1.kolih(); kkk++)
+ for(int nomer=0; nomer < dod5->innn_per1d1.kolih(); nomer++)
+  {
+   iceb_tu_polen(dod5->innn_per1d1.ravno(nomer),&in1,1,'|');  
+   if(iceb_tu_SRAV(dod5->innn1d1.ravno(kkk),in1.ravno(),0) != 0)
+     continue;
+
+   iceb_tu_polen(dod5->innn_per1d1.ravno(nomer),&iceb_tu_period,2,'|');  
+   iceb_tu_rsdat1(&m,&g,iceb_tu_period.ravno());
+
+   suma_bez_nds=dod5->suma_bez_nds1d1.ravno(nomer);
+   suma_nds=dod5->suma_nds1d1.ravno(nomer);
+
+   if(proc_dot != 0.)
+    {
+     suma_bez_nds=suma_bez_nds*(100.0-proc_dot)/100.;
+     suma_bez_nds=iceb_tu_okrug(suma_bez_nds,0.01);
+
+      suma_nds=suma_nds*(100.0-proc_dot)/100.;
+      suma_nds=iceb_tu_okrug(suma_nds,0.01);
+      if(metka_v == 1)
+       {
+        suma_bez_nds=dod5->suma_bez_nds1.suma()-suma_bez_nds;
+        suma_nds=dod5->suma_nds1.suma()-suma_nds;
+       }
+     }
+
+    i_suma_bez_nds+=suma_bez_nds;
+    i_suma_nds+=suma_nds;
+
+    fprintf(ff_svod,"%5d|%-*s|%02d.%04d          |%10.2f|%10.2f|%10s|%s\n",
+    nomer+1,
+    iceb_tu_kolbait(20,dod5->innn1d1.ravno(kkk)),dod5->innn1d1.ravno(kkk),
+    m,g,suma_bez_nds,suma_nds,
+    "",
+    dod5->naim_kontr1d1.ravno(kkk));
+
+    if(dod5->innn1d1.ravno(kkk)[0] == '\0' ||  isdigit(dod5->innn1d1.ravno(kkk)[0]) == 0)  //Значит символ не число
+     fprintf(ff_xml,"   <T4RXXXXG2 xsi:nil=\"true\" ROWNUM=\"%d\"/>\n",nomer+1);
+    else  
+      fprintf(ff_xml,"   <T4RXXXXG2 ROWNUM=\"%d\">%s</T4RXXXXG2>\n",nomer+1,dod5->innn1d1.ravno(kkk));
+
+    fprintf(ff_xml,"   <T4RXXXXG3A ROWNUM=\"%d\">%d</T4RXXXXG3A>\n",nomer+1,m);
+    fprintf(ff_xml,"   <T4RXXXXG3B ROWNUM=\"%d\">%d</T4RXXXXG3B>\n",nomer+1,g);
+    fprintf(ff_xml,"   <T4RXXXXG4 ROWNUM=\"%d\">%.2f</T4RXXXXG4>\n",nomer+1,suma_bez_nds);
+    fprintf(ff_xml,"   <T4RXXXXG5 ROWNUM=\"%d\">%.2f</T4RXXXXG5>\n",nomer+1,suma_nds);
+
+  }
+
+if(dod5->innn1d1.kolih() == 0)
+ {
+  fprintf(ff_svod,"\
+     |                    |                 |          |          |          |\n");
+ }
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+
+fprintf(ff_svod,"\
+Усього за звітний період                    |%10.2f|%10.2f|%10s|\n",i_suma_bez_nds,i_suma_nds,"");
+fprintf(ff_svod,"\
+------------------------------------------------------------------------------\n");
+
+
+
+
+if(i_suma_bez_nds == 0.)
+  fprintf(ff_xml,"   <R06G4 xsi:nil=\"true\"/>\n");
+else
+  fprintf(ff_xml,"   <R06G4>%.2f</R06G4>\n",i_suma_bez_nds);
+
 
 
 class iceb_t_fioruk_rk rekruk;
@@ -617,7 +726,7 @@ fclose(ff_xml);
 /***********************/
 /*шапка второго раздела*/
 /***********************/
-void rnnrd5_8_sap2(FILE *ff)
+void rnnrd5_6_sap2(FILE *ff)
 {
 fprintf(ff,"\nРозділ ІІ. Податковий кредит\n");
 fprintf(ff,"\
@@ -636,4 +745,9 @@ fprintf(ff,"\
 ***********/
 fprintf(ff,"\
 ------------------------------------------------------------------------------\n");
+fprintf(ff,"\
+Операції з придбання з ПДВ, які надають право формування податкового\n\
+                  кредиту\n");
+fprintf(ff,"\
+------------------------------------------------------------------------------\n");
 }
\ No newline at end of file
