@@ -1,4 +1,4 @@
-/* $Id: rozprod.c,v 5.62 2013/11/05 10:50:49 sasa Exp $ */
+/* $Id:$ */
 /*15.07.2015	01.02.1999	Белых А.И.	rozprod.c
 Розничная продажа
 */
@@ -1030,12 +1030,12 @@ extern class iceb_tu_str fio;
 move(0,0);
 
 attron(A_BOLD); /*Повышенная яркость*/
-attron(COLOR_PAIR(COLOR_YELLOW*COLORS+COLOR_BLUE));
+attron(COLOR_PAIR(COLOR_YELLOW*XTERM_COLORS+COLOR_BLUE));
 
 printw(gettext("\
                               Розничная торговля.                              "));
 
-attroff(COLOR_PAIR(COLOR_YELLOW*COLORS+COLOR_BLUE));
+attroff(COLOR_PAIR(COLOR_YELLOW*XTERM_COLORS+COLOR_BLUE));
 
 move(1,0);
 printw("%s %8.2f %s%d.%d.%d %s%d %s:%.2f",
@@ -1057,11 +1057,11 @@ gettext("Кассир:"),fio.ravno());
 
 attroff(A_BOLD); /*Повышенная яркость*/
 
-attron(COLOR_PAIR(COLOR_BLACK*COLORS+COLOR_GREEN));
+attron(COLOR_PAIR(COLOR_BLACK*XTERM_COLORS+COLOR_GREEN));
 printw(gettext("\
 Код.м.    Наименование товара       Ед.изм. Колич.   Цена      Сумма           \n"));
 
-attroff(COLOR_PAIR(COLOR_BLACK*COLORS+COLOR_GREEN));
+attroff(COLOR_PAIR(COLOR_BLACK*XTERM_COLORS+COLOR_GREEN));
 
 helstr(LINES-1,0,"F1",gettext("помощь"),
 "F2",gettext("выб.товара"),
