@@ -1,4 +1,4 @@
-/*$Id: vvod.c,v 5.17 2013/05/17 14:56:32 sasa Exp $*/
+/*$Id:$*/
 /*31.12.2017    02.11.1992      Белых А.И.      vvod.c
 Подпрограмма общего ввода данных
 Все данные вводятся в символьном виде
@@ -225,55 +225,55 @@ if(has_colors() != 0)  //Цветной
    {
     case 0: //Меню ввода данных
      
-     CSZ |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLUE);
-     CFV |= A_BOLD | COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_GREEN);
-     CFR |= COLOR_PAIR( COLOR_RED*COLORS+COLOR_BLUE);
-     CFS |= A_BOLD | COLOR_PAIR( COLOR_RED*COLORS+COLOR_WHITE);
-     CFM |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLACK);
-     CB |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLACK);
+     CSZ |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLUE);
+     CFV |= A_BOLD | COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_GREEN);
+     CFR |= COLOR_PAIR( COLOR_RED*XTERM_COLORS+COLOR_BLUE);
+     CFS |= A_BOLD | COLOR_PAIR( COLOR_RED*XTERM_COLORS+COLOR_WHITE);
+     CFM |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLACK);
+     CB |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLACK);
      break;
 
     case 1: //Меню danet
-     CSZ |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_RED);
-     CFR |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_RED);
-     CFS |= A_BOLD | COLOR_PAIR( COLOR_BLUE*COLORS+COLOR_WHITE);
-     CFM |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_RED);
-     CB |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLACK);
+     CSZ |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_RED);
+     CFR |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_RED);
+     CFS |= A_BOLD | COLOR_PAIR( COLOR_BLUE*XTERM_COLORS+COLOR_WHITE);
+     CFM |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_RED);
+     CB |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLACK);
      break;
 
     case 2: //Настройка для vvod1 меню
-     CFR |= COLOR_PAIR( COLOR_BLUE*COLORS+COLOR_MAGENTA);
-     CFS |= A_BOLD | COLOR_PAIR(COLOR_RED*COLORS+COLOR_WHITE);
-     CFM |= COLOR_PAIR(COLOR_WHITE*COLORS+COLOR_MAGENTA);
-     CB |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLACK);
-     CFV |= A_BOLD |COLOR_PAIR(COLOR_WHITE*COLORS+COLOR_GREEN);
+     CFR |= COLOR_PAIR( COLOR_BLUE*XTERM_COLORS+COLOR_MAGENTA);
+     CFS |= A_BOLD | COLOR_PAIR(COLOR_RED*XTERM_COLORS+COLOR_WHITE);
+     CFM |= COLOR_PAIR(COLOR_WHITE*XTERM_COLORS+COLOR_MAGENTA);
+     CB |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLACK);
+     CFV |= A_BOLD |COLOR_PAIR(COLOR_WHITE*XTERM_COLORS+COLOR_GREEN);
      break;
 
     case 3: //Настройка для menu3
-     CSZ |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLUE);
-     CFR |= COLOR_PAIR(COLOR_RED*COLORS+COLOR_BLUE);
-     CFS |= A_BOLD | COLOR_PAIR( COLOR_RED*COLORS+COLOR_WHITE);
-     CFM |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLUE);
-     CB |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLACK);
-     CFV |= A_BOLD | COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_GREEN);
+     CSZ |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLUE);
+     CFR |= COLOR_PAIR(COLOR_RED*XTERM_COLORS+COLOR_BLUE);
+     CFS |= A_BOLD | COLOR_PAIR( COLOR_RED*XTERM_COLORS+COLOR_WHITE);
+     CFM |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLUE);
+     CB |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLACK);
+     CFV |= A_BOLD | COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_GREEN);
      break;
 
     case 4: //Настройка для menu3 с заголовком другого цвета
-     CSZ |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLACK);
-     CFR |= COLOR_PAIR(COLOR_RED*COLORS+COLOR_BLUE);
-     CFS |= A_BOLD | COLOR_PAIR( COLOR_RED*COLORS+COLOR_WHITE);
-     CFM |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLUE);
-     CB |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLACK);
-     CFV |= A_BOLD | COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_GREEN);
+     CSZ |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLACK);
+     CFR |= COLOR_PAIR(COLOR_RED*XTERM_COLORS+COLOR_BLUE);
+     CFS |= A_BOLD | COLOR_PAIR( COLOR_RED*XTERM_COLORS+COLOR_WHITE);
+     CFM |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLUE);
+     CB |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLACK);
+     CFV |= A_BOLD | COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_GREEN);
      break;
 
     default:
-     CSZ |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLUE);
-     CFR |= COLOR_PAIR(COLOR_RED*COLORS+COLOR_BLUE);
-     CFS |= A_BOLD | COLOR_PAIR( COLOR_RED*COLORS+COLOR_WHITE);
-     CFM |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLUE);
-     CB |= COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_BLACK);
-     CFV |= A_BOLD | COLOR_PAIR( COLOR_WHITE*COLORS+COLOR_GREEN);
+     CSZ |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLUE);
+     CFR |= COLOR_PAIR(COLOR_RED*XTERM_COLORS+COLOR_BLUE);
+     CFS |= A_BOLD | COLOR_PAIR( COLOR_RED*XTERM_COLORS+COLOR_WHITE);
+     CFM |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLUE);
+     CB |= COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_BLACK);
+     CFV |= A_BOLD | COLOR_PAIR( COLOR_WHITE*XTERM_COLORS+COLOR_GREEN);
      break;
 
    }
