@@ -1,5 +1,5 @@
 /* $Id:$ */
-/*09.04.2021    10.12.1993      Белых А.И.      zarnast.c
+/*25.01.2026    10.12.1993      Белых А.И.      zarnast.c
 Читаем настройку на зарплату
 */
 #include        "buhg.h"
@@ -83,12 +83,18 @@ int kekv_nfo=0; //Код экономической классификации 
 
 short		vplsh; /*0-двух уровневый план счетов 1-многоуровневый*/
 
+/*Переменные для расчёта доли подоходного налога приходящиеся на указанные начисления*/
+/************************/
+class iceb_tu_spisok skndr; /*список кодов начисления для любого количества настроек расчёта*/
+class iceb_tu_int kudzr;    /*код удержания для каждой строки списка начислений*/
+/************************/
+
 int             zarnast(void)
 {
 int		i;
 class iceb_tu_str str("");
 class iceb_tu_str bros("");
-
+short metka_skndr=0; /*1-была настройка начислений 0-не была*/
 
 dop_zar_sheta.free_class(); /*Обнуляем список*/
 dop_zar_sheta_spn.free_class(); /*Обнуляем список*/
@@ -107,6 +113,15 @@ kodpn_all.new_plus("");
 
 kodvn=kodvs_b=0;
 
+
+
+
+if(kudzr.kolih() > 0)
+ kudzr.free_class(); 
+
+if(skndr.kolih() > 0)
+ skndr.free_class(); 
+
 kodvn_nvr.new_plus("");
 if(ktnvr_komand != NULL)
  {
@@ -299,6 +314,25 @@ while(cur_alx.read_cursor(&row_alx) != 0)
   class iceb_tu_str spisok_kodov("");
 
 
+  if(iceb_tu_SRAV(str.ravno(),"Коды начислений для расчёта доли подоходного налога",0) == 0)
+   {
+    iceb_tu_polen(row_alx[0],&bros,2,'|');
+    if(bros.getdlinna() > 1)
+     {
+      skndr.plus(bros.ravno());
+      metka_skndr=1;
+     }
+   }
+  if(iceb_tu_SRAV(str.ravno(),"Код удержания для доли подоходного налога",0) == 0)
+   {
+    if(metka_skndr == 1)
+     {
+      iceb_tu_polen(row_alx[0],&bros,2,'|');
+      kudzr.plus(bros.ravno_atoi());
+     }
+    metka_skndr=0;
+   }
+
   if(iceb_tu_SRAV(str.ravno(),"Бюджетные счета",0) == 0)
    {
      iceb_tu_polen(row_alx[0],&bros,2,'|');
@@ -741,6 +775,7 @@ while(cur_alx.read_cursor(&row_alx) != 0)
 
  }
 
+
 /*Чтение настроек для расчёта единого социального взноса*/
 zarrnesv();
 
